"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentReactions = exports.CommentReactionSwitcher = void 0;
const tslib_1 = require("tslib");
const mobx_react_lite_1 = require("mobx-react-lite");
const react_1 = tslib_1.__importDefault(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const components_1 = require("@opensumi/ide-core-browser/lib/components");
const actions_1 = require("@opensumi/ide-core-browser/lib/components/actions");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const ide_theme_1 = require("@opensumi/ide-theme");
const common_1 = require("../common");
const comments_module_less_1 = tslib_1.__importDefault(require("./comments.module.less"));
exports.CommentReactionSwitcher = (0, mobx_react_lite_1.observer)(({ thread, comment, className }) => {
    const key = `${thread.providerId}_${thread.id}_${comment.id}`;
    const menuId = `${next_1.MenuId.CommentReactionSwitcherMenu}_${key}`;
    const menuRegistry = (0, ide_core_browser_1.useInjectable)(next_1.IMenuRegistry);
    const menuService = (0, ide_core_browser_1.useInjectable)(next_1.AbstractMenuService);
    react_1.default.useEffect(() => {
        const disposer = new ide_core_browser_1.Disposable();
        const subMenuId = `${next_1.MenuId.CommentReactionSwitcherSubmenu}_${key}`;
        disposer.addDispose(menuRegistry.registerMenuItem(menuId, {
            submenu: subMenuId,
            // 目前 label 必须要填
            label: subMenuId,
            iconClass: (0, ide_core_browser_1.getExternalIcon)('reactions'),
            group: 'navigation',
        }));
        disposer.addDispose(menuRegistry.registerMenuItems(subMenuId, comment.reactions.map((reaction) => ({
            command: {
                id: common_1.SwitchCommandReaction,
                label: reaction.label,
            },
            extraTailArgs: [
                {
                    thread,
                    comment,
                    reaction,
                },
            ],
        }))));
        return () => disposer.dispose();
    }, []);
    const reactionsContext = react_1.default.useMemo(() => {
        const menu = menuService.createMenu(menuId);
        return menu;
    }, []);
    return react_1.default.createElement(actions_1.InlineActionBar, { className: className, menus: reactionsContext, regroup: (nav) => [nav, []], type: 'icon' });
});
exports.CommentReactions = (0, mobx_react_lite_1.observer)(({ thread, comment }) => {
    var _a;
    const eventBus = (0, ide_core_browser_1.useInjectable)(ide_core_browser_1.IEventBus);
    const iconService = (0, ide_core_browser_1.useInjectable)(ide_theme_1.IIconService);
    const handleClickReaction = react_1.default.useCallback((reaction) => {
        eventBus.fire(new common_1.CommentReactionClick({
            thread,
            comment,
            reaction,
        }));
    }, []);
    return (react_1.default.createElement("div", { className: comments_module_less_1.default.comment_reactions }, (_a = comment.reactions) === null || _a === void 0 ? void 0 : _a.filter((reaction) => reaction.count !== 0).map((reaction) => (react_1.default.createElement(components_1.Button, { key: reaction.label, onClick: () => handleClickReaction(reaction), type: 'secondary', size: 'small', title: reaction.label, className: comments_module_less_1.default.comment_reaction, iconClass: iconService.fromIcon('', reaction.iconPath.toString(), ide_theme_1.IconType.Background) },
        "\u00A0",
        reaction.count)))));
});
//# sourceMappingURL=comment-reactions.view.js.map