"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsZoneWidget = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const mobx_react_lite_1 = require("mobx-react-lite");
const react_1 = tslib_1.__importDefault(require("react"));
const client_1 = tslib_1.__importDefault(require("react-dom/client"));
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const actions_1 = require("@opensumi/ide-core-browser/lib/components/actions");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const ide_monaco_enhance_1 = require("@opensumi/ide-monaco-enhance");
const common_1 = require("../common");
const comments_item_view_1 = require("./comments-item.view");
const comments_textarea_view_1 = require("./comments-textarea.view");
const comments_zone_service_1 = require("./comments-zone.service");
const comments_module_less_1 = tslib_1.__importDefault(require("./comments.module.less"));
const CommentsZone = (0, mobx_react_lite_1.observer)(({ thread, widget }) => {
    const { comments, threadHeaderTitle, contextKeyService } = thread;
    const injector = (0, ide_core_browser_1.useInjectable)(di_1.INJECTOR_TOKEN);
    const commentsZoneService = injector.get(comments_zone_service_1.CommentsZoneService, [thread]);
    const commentsFeatureRegistry = (0, ide_core_browser_1.useInjectable)(common_1.ICommentsFeatureRegistry);
    const fileUploadHandler = react_1.default.useMemo(() => commentsFeatureRegistry.getFileUploadHandler(), []);
    const [replyText, setReplyText] = react_1.default.useState('');
    const commentIsEmptyContext = react_1.default.useMemo(() => contextKeyService.createKey('commentIsEmpty', !replyText), []);
    const commentThreadTitle = commentsZoneService.commentThreadTitle;
    const commentThreadContext = commentsZoneService.commentThreadContext;
    const onChangeReply = react_1.default.useCallback((event) => {
        const { value } = event.target;
        setReplyText(value);
        commentIsEmptyContext.set(!value);
    }, []);
    const placeholder = react_1.default.useMemo(() => {
        var _a;
        return ((_a = commentsFeatureRegistry.getProviderFeature(thread.providerId)) === null || _a === void 0 ? void 0 : _a.placeholder) ||
            `${(0, ide_core_browser_1.localize)('comments.reply.placeholder')}...`;
    }, []);
    const handleDragFiles = react_1.default.useCallback(async (files) => {
        if (fileUploadHandler) {
            const appendText = await fileUploadHandler(replyText, files);
            setReplyText((text) => {
                const value = text + appendText;
                commentIsEmptyContext.set(!value);
                return value;
            });
        }
    }, [replyText]);
    react_1.default.useEffect(() => {
        const disposer = widget.onFirstDisplay(() => {
            setTimeout(() => {
                widget.coreEditor.monacoEditor.revealLine(thread.range.startLineNumber + 1);
            }, 0);
        });
        return () => {
            disposer.dispose();
        };
    }, []);
    return (react_1.default.createElement("div", { className: (0, classnames_1.default)(thread.options.threadClassName, comments_module_less_1.default.comment_container) },
        react_1.default.createElement("div", { className: (0, classnames_1.default)(thread.options.threadHeadClassName, comments_module_less_1.default.head) },
            react_1.default.createElement("div", { className: comments_module_less_1.default.review_title }, threadHeaderTitle),
            react_1.default.createElement(actions_1.InlineActionBar, { menus: commentThreadTitle, context: [
                    {
                        thread,
                        widget,
                        menuId: next_1.MenuId.CommentsCommentThreadTitle,
                    },
                ], separator: 'inline', type: 'icon' })),
        react_1.default.createElement("div", { className: comments_module_less_1.default.comment_body }, comments.length > 0 ? (react_1.default.createElement(comments_item_view_1.CommentItem, { widget: widget, commentThreadContext: commentThreadContext, thread: thread })) : (react_1.default.createElement("div", null,
            react_1.default.createElement(comments_textarea_view_1.CommentsTextArea, { focusDelay: 100, initialHeight: 'auto', value: replyText, onChange: onChangeReply, placeholder: placeholder, dragFiles: handleDragFiles }),
            react_1.default.createElement("div", { className: comments_module_less_1.default.comment_bottom_actions },
                react_1.default.createElement(actions_1.InlineActionBar, { className: comments_module_less_1.default.comment_reply_actions, separator: 'inline', type: 'button', context: [
                        {
                            text: replyText,
                            widget,
                            thread,
                            menuId: next_1.MenuId.CommentsCommentThreadContext,
                        },
                    ], menus: commentThreadContext })))))));
});
let CommentsZoneWidget = class CommentsZoneWidget extends ide_monaco_enhance_1.ResizeZoneWidget {
    _fillContainer() { }
    constructor(editor, thread, options) {
        super(editor.monacoEditor, thread.range, options);
        this._onShow = new ide_core_browser_1.Emitter();
        this.onShow = this._onShow.event;
        this._onHide = new ide_core_browser_1.Emitter();
        this.onHide = this._onHide.event;
        this._editor = editor;
        this._wrapper = document.createElement('div');
        this._isShow = !thread.isCollapsed;
        this._container.appendChild(this._wrapper);
        this.observeContainer(this._wrapper);
        const customRender = this.commentsFeatureRegistry.getZoneWidgetRender();
        client_1.default.createRoot(this._wrapper).render(react_1.default.createElement(ide_core_browser_1.ConfigProvider, { value: this.appConfig }, customRender ? customRender(thread, this) : react_1.default.createElement(CommentsZone, { thread: thread, widget: this })));
    }
    get coreEditor() {
        return this._editor;
    }
    get isShow() {
        return this._isShow;
    }
    show() {
        super.show();
        this._isShow = true;
        this._onShow.fire();
    }
    hide() {
        super.dispose();
        this._isShow = false;
        this._onHide.fire();
    }
    toggle() {
        if (this._isShow) {
            this.hide();
        }
        else {
            this.show();
        }
    }
    applyClass() {
        // noop
    }
    applyStyle() {
        // noop
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.AppConfig),
    tslib_1.__metadata("design:type", Object)
], CommentsZoneWidget.prototype, "appConfig", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(common_1.ICommentsFeatureRegistry),
    tslib_1.__metadata("design:type", Object)
], CommentsZoneWidget.prototype, "commentsFeatureRegistry", void 0);
CommentsZoneWidget = tslib_1.__decorate([
    (0, di_1.Injectable)({ multiple: true }),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object])
], CommentsZoneWidget);
exports.CommentsZoneWidget = CommentsZoneWidget;
//# sourceMappingURL=comments-zone.view.js.map